@@ -4,7 +4,7 @@ UNDEFINED = runtime.UNDEFINED
 __M_dict_builtin = dict
 __M_locals_builtin = locals
 _magic_number = 6
-_modified_time = 1326343307.95461
+_modified_time = 1326428737.681867
 _template_filename='/mnt/md0/MyWork/MyProjects/PyCK/pyck/forms/templates/form_as_p.mako'
 _template_uri='form_as_p.mako'
 _template_cache=cache.Cache(__name__, _modified_time)
@@ -54,11 +54,8 @@ def render_body(context,**pageargs):
             # SOURCE LINE 18
             if 'top' == labels_position:
                 # SOURCE LINE 19
-                __M_writer(u'<label for="')
-                __M_writer(unicode(field.name))
-                __M_writer(u'">')
                 __M_writer(unicode(field.label))
-                __M_writer(u'</label><br /> ')
+                __M_writer(u'<br /> ')
                 pass
             # SOURCE LINE 22
             if field_errors and 'top'==errors_position:
@@ -69,11 +66,8 @@ def render_body(context,**pageargs):
             # SOURCE LINE 26
             if 'left' == labels_position:
                 # SOURCE LINE 27
-                __M_writer(u'<label for="')
-                __M_writer(unicode(field.name))
-                __M_writer(u'">')
                 __M_writer(unicode(field.label))
-                __M_writer(u'</label> ')
+                __M_writer(u' ')
                 pass
             # SOURCE LINE 30
             if field_errors and 'left'==errors_position:
@@ -87,11 +81,9 @@ def render_body(context,**pageargs):
             # SOURCE LINE 35
             if 'bottom' == labels_position:
                 # SOURCE LINE 36
-                __M_writer(u'<label for="')
-                __M_writer(unicode(field.name))
-                __M_writer(u'">')
+                __M_writer(u'<br />')
                 __M_writer(unicode(field.label))
-                __M_writer(u'</label> ')
+                __M_writer(u' ')
                 pass
             # SOURCE LINE 39
             if field_errors and 'bottom'==errors_position:
@@ -103,11 +95,8 @@ def render_body(context,**pageargs):
             # SOURCE LINE 43
             if 'right' == labels_position:
                 # SOURCE LINE 44
-                __M_writer(u'<label for="')
-                __M_writer(unicode(field.name))
-                __M_writer(u'">')
                 __M_writer(unicode(field.label))
-                __M_writer(u'</label> ')
+                __M_writer(u' ')
                 pass
             # SOURCE LINE 47
             if field_errors and 'right'==errors_position:
